@@ -200,11 +200,7 @@ drag_begin_cb (GtkWidget          *widget,
 
   gtk_widget_hide (widget);
 
-#if GTK_CHECK_VERSION (2, 16, 0)
   action = gtk_activatable_get_related_action (GTK_ACTIVATABLE (widget));
-#else
-  action = gtk_widget_get_action (widget);
-#endif
 
   if (action == NULL) return;
 
@@ -231,11 +227,7 @@ drag_end_cb (GtkWidget          *widget,
     {
       gtk_widget_show (widget);
 
-#if GTK_CHECK_VERSION (2, 16, 0)
       action = gtk_activatable_get_related_action (GTK_ACTIVATABLE (widget));
-#else
-      action = gtk_widget_get_action (widget);
-#endif
 
       if (action == NULL) return;
 
@@ -509,11 +501,7 @@ configure_item_tooltip (GtkToolItem *item)
 {
   GtkAction *action;
 
-#if GTK_CHECK_VERSION (2, 16, 0)
   action = gtk_activatable_get_related_action (GTK_ACTIVATABLE (item));
-#else
-  action = gtk_widget_get_action (GTK_WIDGET (item));
-#endif
 
   if (action != NULL)
     {
@@ -561,8 +549,13 @@ action_sensitive_cb (GtkAction   *action,
                      GParamSpec  *pspec,
                      GtkToolItem *item)
 {
-  EggEditableToolbar *etoolbar = EGG_EDITABLE_TOOLBAR
-    (gtk_widget_get_ancestor (GTK_WIDGET (item), EGG_TYPE_EDITABLE_TOOLBAR));
+  EggEditableToolbar *etoolbar;
+  GtkWidget *ancestor = gtk_widget_get_ancestor (GTK_WIDGET (item), EGG_TYPE_EDITABLE_TOOLBAR);
+
+  if (!ancestor)
+    return;
+
+  etoolbar = EGG_EDITABLE_TOOLBAR (ancestor);
 
   if (etoolbar->priv->edit_mode > 0)
     {
