@@ -51,10 +51,6 @@
 #include "eom-exif-details.h"
 #endif
 
-#if GTK_CHECK_VERSION(3, 0, 0)
- 	#define gtk_widget_hide_all(w) gtk_widget_hide(w)
-#endif
-
 #define EOM_PROPERTIES_DIALOG_GET_PRIVATE(object) \
 	(G_TYPE_INSTANCE_GET_PRIVATE ((object), EOM_TYPE_PROPERTIES_DIALOG, EomPropertiesDialogPrivate))
 
@@ -165,11 +161,7 @@ pd_update_general_tab (EomPropertiesDialog *prop_dlg,
 	gtk_label_set_text (GTK_LABEL (prop_dlg->priv->type_label), type_str);
 
 	bytes = eom_image_get_bytes (image);
-#if GLIB_CHECK_VERSION (2, 30, 0)
 	bytes_str = g_format_size (bytes);
-#else
-	bytes_str = g_format_size_for_display (bytes);
-#endif
 
 	gtk_label_set_text (GTK_LABEL (prop_dlg->priv->bytes_label), bytes_str);
 
@@ -193,7 +185,7 @@ eom_exif_set_label (GtkWidget *w, ExifData *exif_data, gint tag_id)
 	gchar *label_text = NULL;
 
 	if (exif_data) {
-		buf_ptr = eom_exif_util_get_value (exif_data, tag_id,
+		buf_ptr = eom_exif_data_get_value (exif_data, tag_id,
 						   exif_buffer, 512);
 
 		if (tag_id == EXIF_TAG_DATE_TIME_ORIGINAL && buf_ptr)
@@ -362,10 +354,10 @@ pd_update_metadata_tab (EomPropertiesDialog *prop_dlg,
 		}
 
 		if (gtk_widget_get_visible (priv->exif_box)) {
-			gtk_widget_hide_all (priv->exif_box);
+			gtk_widget_hide (priv->exif_box);
 		}
 		if (gtk_widget_get_visible (priv->metadata_details_box)) {
-			gtk_widget_hide_all (priv->metadata_details_box);
+			gtk_widget_hide (priv->metadata_details_box);
 		}
 
 		return;
@@ -375,7 +367,7 @@ pd_update_metadata_tab (EomPropertiesDialog *prop_dlg,
 		if (priv->netbook_mode &&
 		    !gtk_widget_get_visible (priv->metadata_details_box)) {
 			gtk_widget_show_all (priv->metadata_details_box);
-			gtk_widget_hide_all (priv->exif_details_expander);
+			gtk_widget_hide (priv->exif_details_expander);
 		}
 	}
 
@@ -545,7 +537,7 @@ eom_properties_dialog_set_netbook_mode (EomPropertiesDialog *dlg,
 		if (gtk_widget_get_visible (priv->exif_box))
 			gtk_widget_show_all (priv->metadata_details_box);
 
-		gtk_widget_hide_all (priv->exif_details_expander);
+		gtk_widget_hide (priv->exif_details_expander);
 	} else {
 		gtk_widget_reparent (priv->metadata_details_sw,
 				     priv->exif_details_expander);
@@ -553,7 +545,7 @@ eom_properties_dialog_set_netbook_mode (EomPropertiesDialog *dlg,
 
 		if (gtk_notebook_get_current_page (GTK_NOTEBOOK (priv->notebook)) == EOM_PROPERTIES_DIALOG_PAGE_DETAILS)
 			gtk_notebook_prev_page (GTK_NOTEBOOK (priv->notebook));
-		gtk_widget_hide_all (priv->metadata_details_box);
+		gtk_widget_hide (priv->metadata_details_box);
 	}
 #endif
 }
@@ -757,7 +749,7 @@ eom_properties_dialog_init (EomPropertiesDialog *prop_dlg)
 	priv->metadata_details_sw = sw;
 
 	if (priv->netbook_mode) {
-		gtk_widget_hide_all (priv->exif_details_expander);
+		gtk_widget_hide (priv->exif_details_expander);
 		gtk_box_pack_start (GTK_BOX (priv->metadata_details_box),
 				    sw, TRUE, TRUE, 6);
 	} else {
@@ -771,8 +763,8 @@ eom_properties_dialog_init (EomPropertiesDialog *prop_dlg)
 			  	dlg);
 
 #ifndef HAVE_EXEMPI
-	gtk_widget_hide_all (xmp_box);
-	gtk_widget_hide_all (xmp_box_label);
+	gtk_widget_hide (xmp_box);
+	gtk_widget_hide (xmp_box_label);
 #endif
 
 #else
