@@ -30,12 +30,9 @@
 #include <glib/gi18n.h>
 #include <glib-object.h>
 #include <gtk/gtk.h>
+#include <math.h>
 #include <string.h>
 
-#if GTK_CHECK_VERSION(3, 0, 0)
- 	#define gtk_widget_hide_all(w) gtk_widget_hide(w)
-#endif
-
 #define EOM_THUMB_NAV_GET_PRIVATE(object) \
 	(G_TYPE_INSTANCE_GET_PRIVATE ((object), EOM_TYPE_THUMB_NAV, EomThumbNavPrivate))
 
@@ -86,6 +83,25 @@ eom_thumb_nav_scroll_event (GtkWidget *widget, GdkEventScroll *event, gpointer u
 	case GDK_SCROLL_RIGHT:
 		break;
 
+#if GTK_CHECK_VERSION (3, 3, 18)
+	case GDK_SCROLL_SMOOTH:
+	{
+		/* Compatibility code to catch smooth events from mousewheels */
+		gdouble x_delta, y_delta;
+		gboolean set = gdk_event_get_scroll_deltas ((GdkEvent*)event,
+							    &x_delta, &y_delta);
+
+		/* Propagate horizontal smooth scroll events further,
+		   as well as non-mousewheel events. */
+		if (G_UNLIKELY (!set) || x_delta != 0.0 || fabs(y_delta) != 1.0)
+			return FALSE;
+
+		/* The y_delta is either +1.0 or -1.0 here */
+		inc *= (gint) y_delta;
+	}
+	break;
+#endif
+
 	default:
 		g_assert_not_reached ();
 		return FALSE;
@@ -487,8 +503,8 @@ eom_thumb_nav_set_show_buttons (EomThumbNav *nav, gboolean show_buttons)
 		gtk_widget_show_all (nav->priv->button_left);
 		gtk_widget_show_all (nav->priv->button_right);
 	} else {
-		gtk_widget_hide_all (nav->priv->button_left);
-		gtk_widget_hide_all (nav->priv->button_right);
+		gtk_widget_hide (nav->priv->button_left);
+		gtk_widget_hide (nav->priv->button_right);
 	}
 }
 
@@ -529,8 +545,13 @@ eom_thumb_nav_set_mode (EomThumbNav *nav, EomThumbNavMode mode)
 	switch (mode)
 	{
 	case EOM_THUMB_NAV_MODE_ONE_ROW:
+#if GTK_CHECK_VERSION (3, 4, 3)
+		gtk_orientable_set_orientation (GTK_ORIENTABLE(priv->thumbview),
+		                                GTK_ORIENTATION_HORIZONTAL);
+#else
 		gtk_icon_view_set_columns (GTK_ICON_VIEW (priv->thumbview),
 					   G_MAXINT);
+#endif
 
 		gtk_widget_set_size_request (priv->thumbview, -1, -1);
 		eom_thumb_view_set_item_height (EOM_THUMB_VIEW (priv->thumbview),
@@ -545,7 +566,12 @@ eom_thumb_nav_set_mode (EomThumbNav *nav, EomThumbNavMode mode)
 		break;
 
 	case EOM_THUMB_NAV_MODE_ONE_COLUMN:
+#if GTK_CHECK_VERSION (3, 4, 3)
+		gtk_orientable_set_orientation (GTK_ORIENTABLE(priv->thumbview),
+		                                GTK_ORIENTATION_VERTICAL);
+#else
 		gtk_icon_view_set_columns (GTK_ICON_VIEW (priv->thumbview), 1);
+#endif
 
 		gtk_widget_set_size_request (priv->thumbview, -1, -1);
 		eom_thumb_view_set_item_height (EOM_THUMB_VIEW (priv->thumbview),
@@ -555,13 +581,18 @@ eom_thumb_nav_set_mode (EomThumbNav *nav, EomThumbNavMode mode)
 						GTK_POLICY_NEVER,
 						GTK_POLICY_AUTOMATIC);
 
-		gtk_widget_hide_all (priv->button_left);
-		gtk_widget_hide_all (priv->button_right);
+		gtk_widget_hide (priv->button_left);
+		gtk_widget_hide (priv->button_right);
 
 		break;
 
 	case EOM_THUMB_NAV_MODE_MULTIPLE_ROWS:
+#if GTK_CHECK_VERSION (3, 4, 3)
+		gtk_orientable_set_orientation (GTK_ORIENTABLE(priv->thumbview),
+		                                GTK_ORIENTATION_VERTICAL);
+#else
 		gtk_icon_view_set_columns (GTK_ICON_VIEW (priv->thumbview), -1);
+#endif
 
 		gtk_widget_set_size_request (priv->thumbview, -1, 220);
 		eom_thumb_view_set_item_height (EOM_THUMB_VIEW (priv->thumbview),
@@ -571,13 +602,18 @@ eom_thumb_nav_set_mode (EomThumbNav *nav, EomThumbNavMode mode)
 						GTK_POLICY_NEVER,
 						GTK_POLICY_AUTOMATIC);
 
-		gtk_widget_hide_all (priv->button_left);
-		gtk_widget_hide_all (priv->button_right);
+		gtk_widget_hide (priv->button_left);
+		gtk_widget_hide (priv->button_right);
 
 		break;
 
 	case EOM_THUMB_NAV_MODE_MULTIPLE_COLUMNS:
+#if GTK_CHECK_VERSION (3, 4, 3)
+		gtk_orientable_set_orientation (GTK_ORIENTABLE(priv->thumbview),
+		                                GTK_ORIENTATION_VERTICAL);
+#else
 		gtk_icon_view_set_columns (GTK_ICON_VIEW (priv->thumbview), -1);
+#endif
 
 		gtk_widget_set_size_request (priv->thumbview, 230, -1);
 		eom_thumb_view_set_item_height (EOM_THUMB_VIEW (priv->thumbview),
@@ -587,8 +623,8 @@ eom_thumb_nav_set_mode (EomThumbNav *nav, EomThumbNavMode mode)
 						GTK_POLICY_NEVER,
 						GTK_POLICY_AUTOMATIC);
 
-		gtk_widget_hide_all (priv->button_left);
-		gtk_widget_hide_all (priv->button_right);
+		gtk_widget_hide (priv->button_left);
+		gtk_widget_hide (priv->button_right);
 
 		break;
 	}
